colour.plotting.dataset.astm_g_173 Module — Colour 0.3.0 documentation

# colour.plotting.dataset.astm_g_173 Module

## ASTM G-173 Solar Spectral Irradiance

Defines the solar spectral irradiance spectral power distribution used in various plotting objects.

References

[1] | http://rredc.nrel.gov/solar/spectra/am1.5/ASTMG173/ASTMG173.html (Last accessed 23 August 2014)

`colour.plotting.dataset.astm_g_173.` `ASTM_G_173_ETR` = <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031da510>

  Extraterrestrial Radiation (solar spectrum at top of atmosphere) at mean Earth-Sun distance.

  ASTM_G_173_ETR : SpectralPowerDistribution